@@ -17,7 +17,7 @@ char do_reverse_endian;
 
 #define AR_MAGIC "!<arch>"
 #define AR_MAGIC_SIZE (sizeof(AR_MAGIC)-1) /* dont count null byte */
-archive_handle *ar_open_fd(const char *filename, int fd)
+archive_handle *ar_open_fd(const char *filename, int fd, bool verbose)
 {
 	static archive_handle ret;
 	char buf[AR_MAGIC_SIZE];
@@ -26,6 +26,7 @@ archive_handle *ar_open_fd(const char *filename, int fd)
 	ret.fd = fd;
 	ret.skip = 0;
 	ret.extfn = NULL;
+	ret.verbose = verbose;
 
 	if (read(ret.fd, buf, AR_MAGIC_SIZE) != AR_MAGIC_SIZE)
 		return NULL;
@@ -34,15 +35,15 @@ archive_handle *ar_open_fd(const char *filename, int fd)
 
 	return &ret;
 }
-archive_handle *ar_open(const char *filename)
+archive_handle *ar_open(const char *filename, bool verbose)
 {
 	int fd;
 	archive_handle *ret;
 
 	if ((fd=open(filename, O_RDONLY)) == -1)
-		err("Could not open '%s'", filename);
+		errp("%s: could not open", filename);
 
-	ret = ar_open_fd(filename, fd);
+	ret = ar_open_fd(filename, fd, verbose);
 	if (ret == NULL)
 		close(fd);
 
@@ -76,13 +77,16 @@ close_and_ret:
 	}
 
 	if ((ret.buf.formatted.magic[0] != '`') || (ret.buf.formatted.magic[1] != '\n')) {
-		warn("Invalid ar entry");
+		/* When dealing with corrupt or random embedded cross-compilers, they might
+		 * be abusing the archive format; only complain when in verbose mode. */
+		if (ar->verbose)
+			warn("%s: invalid ar entry", ar->filename);
 		goto close_and_ret;
 	}
 
 	if (ret.buf.formatted.name[0] == '/' && ret.buf.formatted.name[1] == '/') {
 		if (ar->extfn != NULL) {
-			warn("Duplicate GNU extended filename section");
+			warn("%s: Duplicate GNU extended filename section", ar->filename);
 			goto close_and_ret;
 		}
 		len = atoi(ret.buf.formatted.size);
@@ -112,7 +116,7 @@ close_and_ret:
 	} else if (s[0] == '/' && s[1] >= '0' && s[1] <= '9') {
 		/* GNU extended filename */
 		if (ar->extfn == NULL) {
-			warn("GNU extended filename without special data section");
+			warn("%s: GNU extended filename without special data section", ar->filename);
 			goto close_and_ret;
 		}
 		s = ar->extfn + atoi(s + 1);
